@@ -183,6 +183,11 @@
     clippy::wildcard_imports
 )]
 
+#[cfg(doctest)]
+// https://github.com/rust-lang/rust/issues/82768
+#[cfg_attr(doctest, cfg_attr(doctest, doc = include_str!("../README.md")))]
+const _README: () = ();
+
 #[cfg(test)]
 #[path = "gen/assert_impl.rs"]
 mod assert_impl;
@@ -566,8 +571,7 @@ impl<'a> Iterator for ParseIter<'a, '_> {
             if let Some(m) = self.prefix_format.find(unlinked) {
                 unlinked = &unlinked[m.end()..];
             }
-            let version =
-                unlink(unlinked.split_once(char::is_whitespace).map_or(unlinked, |x| x.0));
+            let version = unlink(unlinked.splitn(2, char::is_whitespace).next().unwrap());
             if !self.version_format.is_match(version) {
                 // Ignore non-release sections that have the same heading
                 // levels as release sections.
