@@ -16,7 +16,11 @@ pub fn trim(s: &str) -> &str {
         cnt += 1;
     }
     // Indents less than 4 are ignored.
-    if cnt < 4 { s[cnt..].trim_end() } else { s.trim_end() }
+    if cnt < 4 {
+        s[cnt..].trim_end()
+    } else {
+        s.trim_end()
+    }
 }
 
 #[track_caller]
